#include <FastLED.h>

#define LED_PIN     26
#define LED_TYPE    WS2812
#define NUM_LEDS    8
#define BRIGHTNESS  50

#define adcPin      32

#define SW_CLOSED   27

#define dirPin      4
#define stepPin     16  
#define enable      23
#define reset       5
#define sleep       17
#define ms1         21
#define ms2         19
#define ms3         18

CRGB leds[NUM_LEDS];

double vout = 1;
const int stepsPerRevolution = 755;

void setup() {
  Serial.begin(115200);
  pinMode(adcPin, INPUT);
  analogSetAttenuation(ADC_2_5db); //reads value from 100 mV to 1250 mV
  

  //feed translation pin declaration
  pinMode(stepPin, OUTPUT);
  pinMode(dirPin, OUTPUT);
  pinMode(enable, OUTPUT);
  pinMode(reset, OUTPUT);
  pinMode(sleep, OUTPUT);
  pinMode(ms1, OUTPUT);
  pinMode(ms2, OUTPUT);
  pinMode(ms3, OUTPUT);
  
  //LED Declaration
  FastLED.addLeds<WS2812, LED_PIN, GRB>(leds, NUM_LEDS);
  FastLED.clear(true);
  FastLED.setBrightness(BRIGHTNESS);
  
  // Limit Switch Declaration
  pinMode(SW_CLOSED,INPUT_PULLUP);

  test_motor();
}

void loop() {
  vout = analogRead(adcPin)*1.25/(4095);
  Serial.println(vout);
  LED_display(vout);
  delay(2000);
}

//FEED TRANSLATION CODE​​
int test_motor()
{
  float newADC = 0;
  float lastADC = 0;
  float highADC = 0;
  int newstep;

  //reset pin must be high 
  digitalWrite(reset, HIGH);
  digitalWrite(sleep, HIGH);
  digitalWrite(ms1, LOW);
  digitalWrite(ms2, LOW);
  digitalWrite(ms3, LOW);
  
  // turn enable on
  digitalWrite(enable, LOW);
  
  // Set motor direction clockwise
  digitalWrite(dirPin, HIGH);
 
  for(int x = 0; x < stepsPerRevolution; x++)
  {
    digitalWrite(stepPin, HIGH);
    delayMicroseconds(6000);
    digitalWrite(stepPin, LOW);
    delayMicroseconds(6000);

    if (digitalRead(SW_CLOSED) == 0){ //switch is closed
      Serial.println("SWITCH CLOSED");
      Serial.println(x);
      break;
    }
  }
  delay(1000); // Wait a second
  
  // Set motor direction counterclockwise
  digitalWrite(dirPin, LOW);
 
  for(int x = 0; x < stepsPerRevolution; x++)
  {
    digitalWrite(stepPin, HIGH);
    delayMicroseconds(6000);
    digitalWrite(stepPin, LOW);
    delayMicroseconds(6000);

    //get new power reading
    newADC = analogRead(adcPin)*1.25/4095;
    //Serial.println(newADC);
    if (newADC > highADC && (newADC - lastADC) < 0.5){
      highADC = newADC;
      LED_display(newADC);
      newstep = stepsPerRevolution - x;
      Serial.print("New High Value = ");
      Serial.println(highADC);
    }
  }
  delay(1000); // Wait a second

  // Set motor direction clockwise again
  digitalWrite(dirPin, HIGH);
 
  for(int x = 0; x < newstep; x++)
  {
    digitalWrite(stepPin, HIGH);
    delayMicroseconds(6000);
    digitalWrite(stepPin, LOW);
    delayMicroseconds(6000);
  }

  // turn enable off
  digitalWrite(enable, HIGH);
  return newstep;
}

void LED_display(double vout){
  int power_input = round((vout/0.8)*8);
  
  if (power_input >= 1){
    leds[0] = CRGB(255, 0, 0);
    FastLED.show();
  } else{
     leds[0] = CRGB(0, 0, 0);
     FastLED.show();
  }

  if (power_input >= 2){
     leds[1] = CRGB(255, 64, 0);
     FastLED.show();
    } else{
     leds[1] = CRGB(0, 0, 0);
     FastLED.show();
  }

  if (power_input >= 3){
      leds[2] = CRGB(255, 128, 0);
      FastLED.show();
  }else{
     leds[2] = CRGB(0, 0, 0);
     FastLED.show();
  }

  if (power_input >= 4){
     leds[3] = CRGB(255, 192, 0);
     FastLED.show();
  }else{
     leds[3] = CRGB(0, 0, 0);
     FastLED.show();
  }

  if (power_input >= 5){
     leds[4] = CRGB(255, 255, 0);
     FastLED.show();
  }else{
     leds[4] = CRGB(0, 0, 0);
     FastLED.show();
  }

  if (power_input >= 6){
     leds[5] = CRGB(170, 255, 0);
     FastLED.show();
  }else{
     leds[5] = CRGB(0, 0, 0);
     FastLED.show();
  }

  if (power_input >= 7){
     leds[6] = CRGB(85, 255, 0);
     FastLED.show();
  }else{
     leds[6] = CRGB(0, 0, 0);
     FastLED.show();
  }

  if (power_input >= 8){
     leds[7] = CRGB(0, 255, 0);
     FastLED.show();
  }else{
     leds[7] = CRGB(0, 0, 0);
     FastLED.show();
  }
}
